<?php

/**
 * @file
 * Administrator page callbacks for the riddle module.
 */

/**
 * Form builder: configure riddle system.
 *
 * @ingroup forms
 * @see system_settings_form()
 */
function riddle_admin_settings() {
  $form['riddle_max_level'] = array(
    '#type' => 'textfield',
    '#title' => t('Set maximum problem level'),
    '#default_value' => variable_get('riddle_max_level', 10),
    '#description' => t('A riddle node cannot be associated with any problem level that is greater than this number'),
    '#required' => TRUE,
    '#size' => 3
  );

  $form['riddle_max_tries'] = array(
    '#type' => 'textfield',
    '#title' => t('Set maximum attempts'),
    '#default_value' => variable_get('riddle_max_tries', 40),
    '#description' => t('This is the default number of maximum attempts for a riddle node'),
    '#required' => TRUE,
    '#size' => 3
  );

  $form['riddle_status'] = array(
    '#type' => 'select',
    '#title' => t('Riddle status'),
    '#description' => t('Please specify Riddle Status: Online/Offline'),
    '#options' => array(
      t('Online'),
      t('Offline'),
    ),
    '#default_value' => variable_get('riddle_status', 0)
  );

  return system_settings_form($form);
}

/**
 * Validation of riddle_admin_settings
 */
function riddle_admin_settings_validate($form, $form_state) {
  $maxlevel = $form_state['values']['riddle_max_level'];
  $maxattempt = $form_state['values']['riddle_max_tries'];
  if (isset($maxlevel) && !is_numeric($maxlevel)) {
    form_set_error('riddle_max_level', t('Maximum level is a number. Please enter a number.'));
  }
  if (isset($maxattempt) && !is_numeric($maxattempt)) {
    form_set_error('riddle_max_tries', t('Maximum attempt is a number. Please enter a number.'));
  }
}
